@@ -41,6 +41,7 @@
 #include "view/searchbar.h"
 #include "view/tabwidget.h"
 #include "view/keylistcontroller.h"
+#include "view/keycacheoverlay.h"
 
 #include "commands/selftestcommand.h"
 #include "commands/importcrlcommand.h"
@@ -252,6 +253,7 @@ MainWindow::Private::UI::UI(MainWindow *q)
     vbox->addWidget(searchBar);
     tabWidget.connectSearchBar(searchBar);
     vbox->addWidget(&tabWidget);
+    new KeyCacheOverlay(mainWidget, q);
 
     q->setCentralWidget(mainWidget);
 }
@@ -347,8 +349,8 @@ void MainWindow::Private::setupActions()
     KStandardAction::preferences(qApp, SLOT(openOrRaiseConfigDialog()), coll);
 
     focusToClickSearchAction = new QAction(i18n("Set Focus to Quick Search"), q);
-    focusToClickSearchAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Q));
     coll->addAction(QStringLiteral("focus_to_quickseach"), focusToClickSearchAction);
+    coll->setDefaultShortcut(focusToClickSearchAction, QKeySequence(Qt::ALT + Qt::Key_Q));
     connect(focusToClickSearchAction, SIGNAL(triggered(bool)), q, SLOT(slotFocusQuickSearch()));
     clipboadMenu = new ClipboardMenu(q);
     clipboadMenu->setMainWindow(q);
