@@ -58,6 +58,7 @@
 #include "commands/deletecertificatescommand.h"
 #include "commands/decryptverifyfilescommand.h"
 #include "commands/signencryptfilescommand.h"
+#include "commands/signencryptfoldercommand.h"
 #include "commands/clearcrlcachecommand.h"
 #include "commands/dumpcrlcachecommand.h"
 #include "commands/dumpcertificatecommand.h"
@@ -70,6 +71,7 @@
 #include "commands/newcertificatecommand.h"
 #include "commands/checksumverifyfilescommand.h"
 #include "commands/checksumcreatefilescommand.h"
+#include "commands/exportpaperkeycommand.h"
 
 #include <Libkleo/Stl_Util>
 
@@ -262,7 +264,9 @@ void KeyListController::setFlatModel(AbstractKeyListModel *model)
 
     if (model) {
         model->clear();
-        model->addKeys(KeyCache::instance()->keys());
+        if (KeyCache::instance()->initialized()) {
+            model->addKeys(KeyCache::instance()->keys());
+        }
         model->setToolTipOptions(d->toolTipOptions());
     }
 }
@@ -277,7 +281,9 @@ void KeyListController::setHierarchicalModel(AbstractKeyListModel *model)
 
     if (model) {
         model->clear();
-        model->addKeys(KeyCache::instance()->keys());
+        if (KeyCache::instance()->initialized()) {
+            model->addKeys(KeyCache::instance()->keys());
+        }
         model->setToolTipOptions(d->toolTipOptions());
     }
 }
@@ -380,6 +386,10 @@ void KeyListController::createActions(KActionCollection *coll)
             "file_export_secret_keys", i18n("Export Secret Keys..."), QString(),
             "view-certificate-export-secret", 0, 0, QString(), false, true
         },
+        {
+            "file_export_paper_key", i18n("Print Secret Key..."), QString(),
+            "document-print", 0, 0, QString(), false, true
+        },
         {
             "file_lookup_certificates", i18n("Lookup Certificates on Server..."), QString(),
             "edit-find", 0, 0, QStringLiteral("Shift+Ctrl+I"), false, true
@@ -396,6 +406,10 @@ void KeyListController::createActions(KActionCollection *coll)
             "file_sign_encrypt_files", i18n("Sign/Encrypt Files..."), QString(),
             "document-edit-sign-encrypt", 0, 0, QString(), false, true
         },
+        {
+            "file_sign_encrypt_folder", i18n("Sign/Encrypt Folder..."), QString(),
+            0/*"folder-edit-sign-encrypt"*/, 0, 0, QString(), false, true
+        },
         {
             "file_checksum_create_files", i18n("Create Checksum Files..."), QString(),
             0/*"document-checksum-create"*/, 0, 0, QString(), false, true
@@ -495,10 +509,12 @@ void KeyListController::createActions(KActionCollection *coll)
     //---
     registerActionForCommand<ExportCertificateCommand>(coll->action(QStringLiteral("file_export_certificates")));
     registerActionForCommand<ExportSecretKeyCommand>(coll->action(QStringLiteral("file_export_secret_keys")));
+    registerActionForCommand<ExportPaperKeyCommand>(coll->action(QStringLiteral("file_export_paper_key")));
     registerActionForCommand<ExportOpenPGPCertsToServerCommand>(coll->action(QStringLiteral("file_export_certificates_to_server")));
     //---
     registerActionForCommand<DecryptVerifyFilesCommand>(coll->action(QStringLiteral("file_decrypt_verify_files")));
     registerActionForCommand<SignEncryptFilesCommand>(coll->action(QStringLiteral("file_sign_encrypt_files")));
+    registerActionForCommand<SignEncryptFolderCommand>(coll->action(QStringLiteral("file_sign_encrypt_folder")));
     //---
     registerActionForCommand<ChecksumCreateFilesCommand>(coll->action(QStringLiteral("file_checksum_create_files")));
     registerActionForCommand<ChecksumVerifyFilesCommand>(coll->action(QStringLiteral("file_checksum_verify_files")));
